==> igniteui-react-layouts-18.0.0.tgz: package/esm5/lib/igr-list-panel-template-item-updating-event-args.js <==
import { IgrListPanelItemModel } from "./igr-list-panel-item-model";
import { ListPanelTemplateItemUpdatingEventArgs as ListPanelTemplateItemUpdatingEventArgs_internal } from "./ListPanelTemplateItemUpdatingEventArgs";
var IgrListPanelTemplateItemUpdatingEventArgs = /** @class */ /*@__PURE__*/ (function () {
    function IgrListPanelTemplateItemUpdatingEventArgs() {
        this._implementation = this.createImplementation();
        this._implementation.externalObject = this;
        this.onImplementationCreated();
    }
    IgrListPanelTemplateItemUpdatingEventArgs.prototype.createImplementation = function () {
        return new ListPanelTemplateItemUpdatingEventArgs_internal();
    };
    Object.defineProperty(IgrListPanelTemplateItemUpdatingEventArgs.prototype, "i", {
        /**
         * @hidden
         */
        get: function () {
            return this._implementation;
        },
        enumerable: false,
        configurable: true
    });
    IgrListPanelTemplateItemUpdatingEventArgs.prototype.onImplementationCreated = function () {
    };
    IgrListPanelTemplateItemUpdatingEventArgs.prototype._provideImplementation = function (i) {
        this._implementation = i;
        this._implementation.externalObject = this;
        this.onImplementationCreated();
    };
    Object.defineProperty(IgrListPanelTemplateItemUpdatingEventArgs.prototype, "model", {
        get: function () {
            if (this.i.a == null) {
                return null;
            }
            if (!this.i.a.externalObject) {
                var e = new IgrListPanelItemModel();
                e._implementation = this.i.a;
                this.i.a.externalObject = e;
            }
            return this.i.a.externalObject;
        },
        set: function (v) {
            v == null ? this.i.a = null : this.i.a = v.i;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrListPanelTemplateItemUpdatingEventArgs.prototype, "content", {
        get: function () {
            return this.i.c;
        },
        set: function (v) {
            this.i.c = v;
        },
        enumerable: false,
        configurable: true
    });
    return IgrListPanelTemplateItemUpdatingEventArgs;
}());
export { IgrListPanelTemplateItemUpdatingEventArgs };

==> igniteui-react-layouts-18.1.0.tgz: package/esm5/lib/igr-list-panel-template-item-updating-event-args.js <==
import { IgrListPanelItemModel } from "./igr-list-panel-item-model";
import { ListPanelTemplateItemUpdatingEventArgs as ListPanelTemplateItemUpdatingEventArgs_internal } from "./ListPanelTemplateItemUpdatingEventArgs";
var IgrListPanelTemplateItemUpdatingEventArgs = /** @class */ /*@__PURE__*/ (function () {
    function IgrListPanelTemplateItemUpdatingEventArgs() {
        this._implementation = this.createImplementation();
        this._implementation.externalObject = this;
        this.onImplementationCreated();
    }
    IgrListPanelTemplateItemUpdatingEventArgs.prototype.createImplementation = function () {
        return new ListPanelTemplateItemUpdatingEventArgs_internal();
    };
    Object.defineProperty(IgrListPanelTemplateItemUpdatingEventArgs.prototype, "i", {
        /**
         * @hidden
         */
        get: function () {
            return this._implementation;
        },
        enumerable: false,
        configurable: true
    });
    IgrListPanelTemplateItemUpdatingEventArgs.prototype.onImplementationCreated = function () {
    };
    IgrListPanelTemplateItemUpdatingEventArgs.prototype._provideImplementation = function (i) {
        this._implementation = i;
        this._implementation.externalObject = this;
        this.onImplementationCreated();
    };
    Object.defineProperty(IgrListPanelTemplateItemUpdatingEventArgs.prototype, "model", {
        get: function () {
            var r = this.i.a;
            if (r == null) {
                return null;
            }
            if (!r.externalObject) {
                var e = new IgrListPanelItemModel();
                if (e.i.setNativeElement) {
                    e.i.setNativeElement(r);
                }
                else {
                    e._implementation = r;
                }
                r.externalObject = e;
            }
            return r.externalObject;
        },
        set: function (v) {
            v == null ? this.i.a = null : this.i.a = v.i;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrListPanelTemplateItemUpdatingEventArgs.prototype, "content", {
        get: function () {
            return this.i.c;
        },
        set: function (v) {
            this.i.c = v;
        },
        enumerable: false,
        configurable: true
    });
    return IgrListPanelTemplateItemUpdatingEventArgs;
}());
export { IgrListPanelTemplateItemUpdatingEventArgs };
